@@ -46,7 +46,7 @@
 
 #define QT_FEATURE_posix_shm 1
 
-#define QT_FEATURE_pthread_clockjoin 1
+#define QT_FEATURE_pthread_clockjoin -1
 
 #define QT_FEATURE_pthread_condattr_setclock 1
 
@@ -64,6 +64,12 @@
 
 #define QT_FEATURE_sysv_shm 1
 
+#define QT_FEATURE_dup3 1
+
+#define QT_FEATURE_accept4 1
+
+#define QT_FEATURE_vxpipedrv -1
+
 #define QT_FEATURE_backtrace 1
 
 #define QT_FEATURE_cxx20_format 1
